summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolderimap.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfolderimap.h')
-rw-r--r--kmail/kmfolderimap.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmail/kmfolderimap.h b/kmail/kmfolderimap.h
index f303325b..c7b31588 100644
--- a/kmail/kmfolderimap.h
+++ b/kmail/kmfolderimap.h
@@ -99,8 +99,8 @@ public:
virtual imapState getSubfolderState() { return mSubfolderState; }
virtual void setSubfolderState(imapState state);
- /** Usually a tqparent is given. But in some cases there is no
- fitting tqparent object available. Then the name of the folder
+ /** Usually a parent is given. But in some cases there is no
+ fitting parent object available. Then the name of the folder
is used as the absolute path to the folder file. */
KMFolderImap(KMFolder* folder, const char* name=0);
virtual ~KMFolderImap();
@@ -321,7 +321,7 @@ public:
virtual bool isMoveable() const;
/** Initialize this storage from another one. Used when creating a child folder */
- void initializeFrom( KMFolderImap* tqparent, TQString path, TQString mimeType );
+ void initializeFrom( KMFolderImap* parent, TQString path, TQString mimeType );
/** Returns the IMAP flags that can be stored on the server. */
int permanentFlags() const { return mPermanentFlags; }
@@ -363,7 +363,7 @@ public slots:
virtual int addMsg(TQPtrList<KMMessage>&, TQValueList<int>& index_return);
/** Copy the messages to this folder */
- void copyMsg(TQPtrList<KMMessage>& msgList/*, KMFolder* tqparent*/);
+ void copyMsg(TQPtrList<KMMessage>& msgList/*, KMFolder* parent*/);
/** Detach message from this folder. Usable to call addMsg() afterwards.
@@ -438,7 +438,7 @@ protected:
/** Create or find the INBOX and initialize it */
void initInbox();
/** See if there is a better tqparent then this folder */
KMFolderImap* findParent( const TQString& path, const TQString& name );
/** See if all folders are still present on server, otherwise delete them */
@@ -438,7 +438,7 @@ protected:
/** Create or find the INBOX and initialize it */
void initInbox();
- /** See if there is a better tqparent then this folder */
+ /** See if there is a better parent then this folder */
KMFolderImap* findParent( const TQString& path, const TQString& name );
/** See if all folders are still present on server, otherwise delete them */